@@ -76,11 +76,9 @@ pub fn create_index(db: &DB, info: &IndexInfo) {
                 t.insert(db, &mut row);
             }
         }
-        // ToDo: initialise the index from table data.
-        if root > SYS_ROOT_LAST
-        /* Should work out better way of doing this test!! */
-        {
+        if root > SYS_ROOT_LAST {
             table.add_index(root, info.cols.clone());
+            table.init_index(db);
         }
     } else {
         panic!("table not found: {}", &info.tname.str());
